<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:java="http://xml.apache.org/xslt/java"
	xmlns:util="xalan://org.greenstone.gsdl3.util.XSLTUtil"
	xmlns:gslib="http://www.greenstone.org/skinning"
	xmlns:gsf="http://www.greenstone.org/greenstone3/schema/ConfigFormat"
	extension-element-prefixes="java util"
	exclude-result-prefixes="java util gsf">

  <!--
	  <img src="interfaces/{$interface_name}/images/iworld.gif"/>
  -->
  
  <xsl:template name="documentHeading">
    <gsf:style src="sites/{$site_name}/collect/{$collName}/css/eurovision.css"/>
    <gsf:script src="sites/{$site_name}/collect/{$collName}/js/eurovision.js"/>
    
    <span style="font-weight:bold; font-size: 120%;">
      <gsf:switch>
        <gsf:metadata name='FromCountry'/>	
        <gsf:when test='exists'>
	  <gsf:metadata name='FromCountry'/>
	  voting in
	  <gsf:metadata name='FromCountryYear'/>
	</gsf:when>
	<gsf:otherwise>
	  <xsl:call-template name="choose-title"/>
	</gsf:otherwise>
      </gsf:switch>
    </span>

    <style>
      table.esc-metadata tr:nth-child(odd) {
        background-color: rgba(255,255,255,0.2);
      }
      table.esc-metadata tr:nth-child(even) {
        background-color: rgba(255,255,255,0.0);
      }
	
      table.esc-metadata {
        margin-top: 20px;
        min-width: 650px;
        padding: 10px;
      }
    </style>

    <!-- prov:wasDerivedFrom -->
    
    <table class="esc-metadata">
      
      <gsf:switch>
        <gsf:metadata name='FromCountry'/>
        <gsf:when test='exists'>
	  <tr>
	    <td>
	      Voting Type:
	    </td>
	    <td>
	      <gsf:switch>
		<gsf:metadata name='FromCountryType'/>	
		<gsf:when test="equals" test-value="J">
		  Jury
		</gsf:when>
		<gsf:otherwise>
		  Televotes
		</gsf:otherwise>
	      </gsf:switch>
	    </td>
	  </tr>	  
	  <tr>
	    <td>
	      Votes cast by:
	    </td>
	    <td>
	      <gsf:metadata name="FromCountry" highlight="highlight" />
	    </td>
	  </tr>
	  <tr>
	    <td>
	      Year:
	    </td>
	    <td>
	      <gsf:metadata name="FromCountryYear" highlight="highlight" />
	    </td>
	  </tr>
	</gsf:when>
	<gsf:otherwise>
<!--	  
      </gsf:switch>
      
      <gsf:switch>
        <gsf:metadata name='Title'/>
        <gsf:when test='exists'>
-->
	  <tr>
	    <td>
	      <!--
	       XX<xsl:value-of select="util:getInterfaceText($interface_name, /page/@lang, 'Artist')"/>XX
	      -->
	      Title:
	    </td>
	    <td>
	      <gsf:switch>
		<gsf:metadata name='WikipediaURL_uri' />
		<gsf:when test='exists'>

		  <a target="_blank">
		    <xsl:attribute name="href">
		      <gsf:metadata name="WikipediaURL_uri" />
		    </xsl:attribute>
		    <gsf:metadata name="Title" highlight="highlight" /> @ Wikipedia
		    <img src="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAAKCAYAAACNMs+9AAAAVklEQVR4Xn3PgQkAMQhDUXfqTu7kTtkpd5RA8AInfArtQ2iRXFWT2QedAfttj2FsPIOE1eCOlEuoWWjgzYaB/IkeGOrxXhqB+uA9Bfcm0lAZuh+YIeAD+cAqSz4kCMUAAAAASUVORK5CYII=" alt="external link" />
		  </a>
		</gsf:when>
		<gsf:otherwise>
		  <gsf:metadata name="Title" highlight="highlight" />
		</gsf:otherwise>
	      </gsf:switch>
	    </td>
	  </tr>
<!--	  
	</gsf:when>
-->
	</gsf:otherwise>
      </gsf:switch>

      <gsf:switch>
        <gsf:metadata name='Creator'/>
        <gsf:when test='exists'>
	  <tr>
	    <td>
	      Artist:
	    </td>
	    <td>
	      <gsf:metadata name="Creator" highlight="highlight" />
	    </td>
	  </tr>
	</gsf:when>
      </gsf:switch>

      <gsf:switch>
        <gsf:metadata name='Country'/>
        <gsf:when test='exists'>
	  <tr>
	    <td>
	      Country:
	    </td>
	    <td>
	      <gsf:metadata name="Country" highlight="highlight" />
	    </td>
	  </tr>
	</gsf:when>
      </gsf:switch>

      <gsf:switch>
        <gsf:metadata name='Year'/>
        <gsf:when test='exists'>
	  <tr>
	    <td>
	      Year:
	    </td>
	    <td>
	      <gsf:metadata name="Year" highlight="highlight" />
	    </td>
	  </tr>
	</gsf:when>
      </gsf:switch>
      
    </table>
    
  </xsl:template>

  <xsl:template name="documentContentFromCountry">
    <div id="from-country-votes">
      <gsf:script>	
	append_from_country_votes(gs.documentMetadata["Identifier"],gs.documentMetadata["FromCountryType"]);
      </gsf:script>
    </div>    
  </xsl:template>
  
  <xsl:template name="documentContentEntry">
    <gsf:switch>
      <gsf:metadata name='Abstract_en'/>
      <gsf:when test='exists'>
	<div style="padding-top: 10px;padding-bottom: 10px; font-style: italic;">
	  <gsf:metadata name='Abstract_en'/>
	</div>
      </gsf:when>
    </gsf:switch>

    <div id="to-country-votes">
      <gsf:script>
	append_to_country_votes("Jury Votes","JuryVotesJSON","JuryVotesTotal");
	append_to_country_votes("Televotes","TeleVotesJSON","TeleVotesTotal");
      </gsf:script>

    </div>

    <div id="find-more-content">
      Find more content about this Eurovision entry on-line:
      <ul>
	<li>
	  <a target="_blank">
	    <xsl:attribute name="href">
	      //www.google.com/search?q=Eurovision+<gsf:metadata name="Title"/>
	    </xsl:attribute>
	    @ Google Web Search (including YouTube)
	    <gsf:space/>
	    <img src="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAAKCAYAAACNMs+9AAAAVklEQVR4Xn3PgQkAMQhDUXfqTu7kTtkpd5RA8AInfArtQ2iRXFWT2QedAfttj2FsPIOE1eCOlEuoWWjgzYaB/IkeGOrxXhqB+uA9Bfcm0lAZuh+YIeAD+cAqSz4kCMUAAAAASUVORK5CYII=" alt="external link" />
	  </a>
	</li>

	<li>
	  <a target="_blank">
	    <xsl:attribute name="href">
	      //www.google.com/search?q=<gsf:metadata name="Creator"/>+<gsf:metadata name="Title"/>+site:genius.com
	    </xsl:attribute>
	    @ Genius.com (lyrics)
	    <gsf:space/>
	    <img src="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAAKCAYAAACNMs+9AAAAVklEQVR4Xn3PgQkAMQhDUXfqTu7kTtkpd5RA8AInfArtQ2iRXFWT2QedAfttj2FsPIOE1eCOlEuoWWjgzYaB/IkeGOrxXhqB+uA9Bfcm0lAZuh+YIeAD+cAqSz4kCMUAAAAASUVORK5CYII=" alt="external link" />
	  </a>
	</li>

	<li>
	  <a target="_blank">
	    <xsl:attribute name="href">
	      //www.google.com/search?q=<gsf:metadata name="Creator"/>+<gsf:metadata name="Title"/>+site:ultimate-guitar.com
	    </xsl:attribute>
	    @ Ultimate-Guitar (chords/tab)
	    <gsf:space/>
	    <img src="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAAKCAYAAACNMs+9AAAAVklEQVR4Xn3PgQkAMQhDUXfqTu7kTtkpd5RA8AInfArtQ2iRXFWT2QedAfttj2FsPIOE1eCOlEuoWWjgzYaB/IkeGOrxXhqB+uA9Bfcm0lAZuh+YIeAD+cAqSz4kCMUAAAAASUVORK5CYII=" alt="external link" />
	  </a>
	</li>
	
	<li>
	  <a target="_blank">
	    <xsl:attribute name="href">
	      //www.google.com/search?q=&quot;<gsf:metadata name="Title"/>&quot; site:musicbrainz.org
	    </xsl:attribute>
	    @ MusicBrainz (music-oriented linked data about the song)
	    <gsf:space/>
	    <img src="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAAKCAYAAACNMs+9AAAAVklEQVR4Xn3PgQkAMQhDUXfqTu7kTtkpd5RA8AInfArtQ2iRXFWT2QedAfttj2FsPIOE1eCOlEuoWWjgzYaB/IkeGOrxXhqB+uA9Bfcm0lAZuh+YIeAD+cAqSz4kCMUAAAAASUVORK5CYII=" alt="external link" />
	  </a>
	</li>
	
	<li>
	  <a target="_blank">
	    <xsl:attribute name="href">
	      <gsf:metadata name="song_robust_uri" />
	    </xsl:attribute>
	    @ DBpedia (direct URI to linked data)
	    <gsf:space/>
	    <img src="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAAKCAYAAACNMs+9AAAAVklEQVR4Xn3PgQkAMQhDUXfqTu7kTtkpd5RA8AInfArtQ2iRXFWT2QedAfttj2FsPIOE1eCOlEuoWWjgzYaB/IkeGOrxXhqB+uA9Bfcm0lAZuh+YIeAD+cAqSz4kCMUAAAAASUVORK5CYII=" alt="external link" />
	  </a>
	</li>
	
	
      </ul>
    </div>
    <!--
        google.com/webhp?##q=yourquery&btnI=I
    -->
    
  </xsl:template>
  
  <xsl:template name="documentContent">

    <gsf:switch>
      <gsf:metadata name='FromCountry'/>
      <gsf:when test='exists'>
	<xsl:call-template name="documentContentFromCountry"/>
      </gsf:when>
      <gsf:otherwise>
	<xsl:call-template name="documentContentEntry"/>
      </gsf:otherwise>
    </gsf:switch>

  </xsl:template>

</xsl:stylesheet>
